Make sure files containing sensitive information are not copied to the Documents directory. If your app does not need
this
functionality, set the `UIFileSharingEnabled` flag in the `Info.plist` file to false or delete the option.
